@@ -8,6 +8,7 @@ Articulation Points
 This example shows how to compute and visualize the `articulation points <https://en.wikipedia.org/wiki/Biconnected_component>`_ in a graph using :meth:`igraph.GraphBase.articulation_points`. For an example on bridges instead, see :ref:`tutorials-bridges`.
 
 """
+
 import igraph as ig
 import matplotlib.pyplot as plt
 
@@ -30,9 +31,9 @@ ig.plot(
     vertex_size=30,
     vertex_color="lightblue",
     vertex_label=range(g.vcount()),
-    vertex_frame_color = ["red" if v in articulation_points else "black" for v in g.vs],
-    vertex_frame_width = [3 if v in articulation_points else 1 for v in g.vs],
+    vertex_frame_color=["red" if v in articulation_points else "black" for v in g.vs],
+    vertex_frame_width=[3 if v in articulation_points else 1 for v in g.vs],
     edge_width=0.8,
-    edge_color='gray'
+    edge_color="gray",
 )
 plt.show()
