@@ -8,16 +8,13 @@ Maximum Flow
 This example shows how to construct a max flow on a directed graph with edge capacities using :meth:`igraph.Graph.maxflow`.
 
 """
+
 import igraph as ig
 import matplotlib.pyplot as plt
 
 # %%
 # First, we generate a graph and assign a "capacity" to each edge:
-g = ig.Graph(
-    6,
-    [(3, 2), (3, 4), (2, 1), (4,1), (4, 5), (1, 0), (5, 0)],
-    directed=True
-)
+g = ig.Graph(6, [(3, 2), (3, 4), (2, 1), (4, 1), (4, 5), (1, 0), (5, 0)], directed=True)
 g.es["capacity"] = [7, 8, 1, 2, 3, 4, 5]
 
 # %%
@@ -39,6 +36,6 @@ ig.plot(
     target=ax,
     layout="circle",
     vertex_label=range(g.vcount()),
-    vertex_color="lightblue"
+    vertex_color="lightblue",
 )
 plt.show()
