@@ -24,6 +24,13 @@ class SimplePropertiesTests(unittest.TestCase):
         self.assertAlmostEqual(7 / 16, self.gdir.density(True), places=5)
         self.assertAlmostEqual(1 / 7, self.tree.density(), places=5)
 
+    def testMeanDegree(self):
+        self.assertEqual(9.0, self.gfull.mean_degree())
+        self.assertEqual(0.0, self.gempty.mean_degree())
+        self.assertEqual(2.5, self.g.mean_degree())
+        self.assertEqual(7 / 4, self.gdir.mean_degree())
+        self.assertAlmostEqual(13 / 7, self.tree.mean_degree(), places=5)
+
     def testDiameter(self):
         self.assertTrue(self.gfull.diameter() == 1)
         self.assertTrue(self.gempty.diameter(unconn=False) == inf)
@@ -496,19 +503,28 @@ class CentralityTests(unittest.TestCase):
 
     def testAuthorityScore(self):
         g = Graph.Tree(15, 2, TREE_IN)
-        asc = g.authority_score()
+        
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            asc = g.authority_score()
         self.assertAlmostEqual(max(asc), 1.0, places=3)
 
         # Smoke testing
-        g.authority_score(scale=False, return_eigenvalue=True)
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            g.authority_score(scale=False, return_eigenvalue=True)
 
     def testHubScore(self):
         g = Graph.Tree(15, 2, TREE_IN)
-        hsc = g.hub_score()
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            hsc = g.hub_score()
         self.assertAlmostEqual(max(hsc), 1.0, places=3)
 
         # Smoke testing
-        g.hub_score(scale=False, return_eigenvalue=True)
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            g.hub_score(scale=False, return_eigenvalue=True)
 
     def testCoreness(self):
         g = Graph.Full(4) + Graph(4) + [(0, 4), (1, 5), (2, 6), (3, 7)]
@@ -817,14 +833,6 @@ class PathTests(unittest.TestCase):
             g.distances(weights="weight", target=[2, 3], algorithm="johnson")
             == [row[2:4] for row in expected]
         )
-        self.assertRaises(
-            ValueError,
-            g.distances,
-            weights="weight",
-            target=[2, 3],
-            algorithm="johnson",
-            mode="in",
-        )
 
     def testGetShortestPath(self):
         g = Graph(4, [(0, 1), (0, 2), (1, 3), (3, 2), (2, 1)], directed=True)
